import ctypes
import os
import platform

if platform.system() == 'Windows':
    lib_name = 'libsegfault.dll'
else:
    lib_name = 'libsegfault.so'

lib_path = os.path.join(os.path.dirname(__file__), '..', lib_name)

if not os.path.exists(lib_path):
    raise FileNotFoundError(f"The library file was not found at: {lib_path}")

try:
    lib = ctypes.CDLL(lib_path)
except OSError as e:
    raise OSError(f"Failed to load library: {e}")

def cause_segfault():
    lib.cause_segfault()



from setuptools import setup, find_packages
import platform

with open("README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name='segfault_package',
    version='0.0.2',
    author='pael',
    description='If you ever missed segfaults in Python, there you go',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/fdmx2301/segfault.git",
    packages=find_packages(),
    package_data={
        'segfault': ['../libsegfault.so', '../libsegfault.dll']
    },
    include_package_data=True,
    python_requires='>=3.6',
)
